@@ -1,6 +1,7 @@
 #[macro_use] extern crate rust_util;
 
 use rust_util::{XResult, SimpleError};
+use rust_util::util_msg::set_logger_std_out;
 
 // cargo run --example log
 fn main() -> XResult<()> {
@@ -20,6 +21,11 @@ error or ^"##);
 
     println!("{:?}", test_opt_result());
 
+    set_logger_std_out(false);
+    information!("Std err!");
+    warning!("Std err!");
+    set_logger_std_out(true);
+
     simple_error!("helloworld {}", 1)
 }
 
